@@ -29,7 +29,7 @@ from kodexa.model.objects import (
     DocumentFamilyEvent,
     ChannelEvent,
     DataObjectEvent,
-    WorkspaceEvent,
+    WorkspaceEvent, DocumentFamily,
 )
 from kodexa.pipeline import PipelineContext, PipelineStatistics
 from kodexa.platform.client import DocumentStoreEndpoint, KodexaClient, process_response
@@ -279,6 +279,12 @@ class KodexaPlatform:
         kodexa_config["_current_profile_"] = profile
         save_config(kodexa_config)
 
+    @classmethod
+    def clear_profile(cls, profile):
+        kodexa_config = get_config(profile)
+        kodexa_config["_current_profile_"] = None
+        save_config(kodexa_config)
+
     @classmethod
     def delete_profile(cls, profile):
         kodexa_config = get_config(profile)
@@ -327,7 +333,7 @@ class KodexaPlatform:
             dict: The server information.
         """
         r = requests.get(
-            f"{KodexaPlatform.get_url()}/api",
+            f"{KodexaPlatform.get_url()}/api/overview",
             headers={
                 "x-access-token": KodexaPlatform.get_access_token(),
                 "cf-access-token": os.environ.get("CF_TOKEN", ""),
@@ -884,7 +890,7 @@ class EventHelper:
             ContentObject: The posted content object.
         """
         files = {"content": content}
-        data = {"contentObjectJson": json.dumps(content_object.dict(by_alias=True))}
+        data = {"contentObjectJson": json.dumps(content_object.model_dump(by_alias=True))}
         logger.info("Posting back content object to execution object")
         co_response = requests.post(
             f"{KodexaPlatform.get_url()}/api/sessions/{self.event.session_id}/executions/{self.event.execution.id}/objects",
@@ -901,7 +907,7 @@ class EventHelper:
 
         return ContentObject.model_validate(co_response.json())
 
-    def build_pipeline_context(self) -> PipelineContext:
+    def build_pipeline_context(self, event) -> PipelineContext:
         """Builds a pipeline context.
 
         Returns:
@@ -911,16 +917,26 @@ class EventHelper:
             context={}, content_provider=self, execution_id=self.event.execution.id
         )
 
-        if self.event.store_ref and self.event.document_family_id:
-            logger.info("We have storeRef and document family")
-            rds: DocumentStoreEndpoint = KodexaClient().get_object_by_ref(
-                "store", self.event.store_ref
-            )
-            document_family = rds.get_family(self.event.document_family_id)
-
-            context.document_family = document_family
-            context.document_store = rds
+        if isinstance(event, dict):
+            event = self.get_base_event(event)
 
+        if isinstance(event, DocumentFamilyEvent):
+            # Can we get the document family
+            dfe:DocumentFamilyEvent = self.event
+            if dfe.document_family:
+                logger.info(f"Setting document family for context: {dfe.document_family}")
+                context.document_family = dfe.document_family
+                logger.info(f"Getting document store for family: {context.document_family.store_ref}")
+                context.document_store = KodexaClient().get_object_by_ref("store", context.document_family.store_ref)
+        if isinstance(event, ContentEvent):
+            ce:ContentEvent = self.event
+            if ce.content_object:
+                logger.info(f"Setting content object for context: {ce.content_object}")
+                context.content_object = ce.content_object
+                context.document_family = ce.document_family
+                logger.info(f"Getting document store for content object: {context.content_object.store_ref}")
+                context.document_store = KodexaClient().get_object_by_ref("store", context.content_object.store_ref)
+        logger.info("Returning context")
         return context
 
     def get_input_document(self, context):
